@@ -26,7 +26,6 @@ def create_upload_data(content_type, source_filename, upload_to):
     access_key = settings.AWS_ACCESS_KEY_ID
     secret_access_key = settings.AWS_SECRET_ACCESS_KEY
     bucket = settings.AWS_STORAGE_BUCKET_NAME
-    endpoint = settings.S3DIRECT_ENDPOINT
 
     expires_in = datetime.now() + timedelta(hours=24)
     expires = expires_in.strftime('%Y-%m-%dT%H:%M:%S.000Z')
@@ -53,7 +52,7 @@ def create_upload_data(content_type, source_filename, upload_to):
         filename = '${filename}'
 
     key = "%s/%s" % (upload_to or S3DIRECT_DIR, filename)
-    bucket_url = "https://%s/%s" % (endpoint, bucket)
+    bucket_url = 'https://s3.amazonaws.com/%s' % bucket
 
     return {
         "policy": policy,
